@@ -15,17 +15,13 @@ use Capture::Tiny ':all';
 
 Net::Hacky::Detect::IP - Hackily try different methods of attaining local system IPs
 
-=head1 WARNING
-
-This module does not yet support returning IPv6 addresses, though will do soon!
-
 =head1 VERSION
 
-Version 0.015
+Version 0.016
 
 =cut
 
-our $VERSION = '0.015';
+our $VERSION = '0.016';
 
 my $tools = {
     unix => {
@@ -98,7 +94,9 @@ sub new {
 
 =head2 scan
 
-Attempt to find local system ips, returns a list of local ips will return a [] black list if nothing found.
+Attempt to find local system ips, accepts no arguments.
+
+Returns a list of local ips for the system, will return a blank [] list if nothing found.
 
 =cut
 
@@ -177,7 +175,7 @@ sub scan {
             # Push the valid ip into the return space
             push @$return,$IP;
         }
-        if ($testIP =~ m#:# && $testIP =~ m#[0-9]# && $testIP =~ m#^([a-f0-9:]+)$#) {
+        elsif ($testIP =~ m#:# && $testIP =~ m#[0-9]# && $testIP =~ m#^([a-f0-9:]+)$#) {
             # Copy $1 to $IP because it looks prettier
             my $IP = $1;
             
